@@ -1,19 +1,28 @@
-#' Embed the graphs Impulse Response Function (IRF) in R Markdown document
+#' Embed the graphs of Impulse Response Function (IRF) in R Markdown document
 #'
 #' Use this function to include \code{Dynare} IRF into the R Markdown document
 #'
-#' @usage include_IRF(model="",IRF="",path="")
 #' @param IRF A character string for the name of the Impulse Response Function as defined in the `Dynare` codes.
+#' @param path A character string for the path to the IRF graph.
 #' @inheritParams run_dynare
 #' @return Set of \code{Dynare} (open-source software for DSGE modelling) outputs
-#' @author Sagiru Mati, ORCID: 0000-0003-1413-3974, https://smati.com.ng
+#' @author [Sagiru Mati](https://smati.com.ng), [ORCID: 0000-0003-1413-3974](https://orcid.org/0000-0003-1413-3974)
 #' * Yusuf Maitama Sule (Northwest) University Kano, Nigeria
 #' * SMATI Academy
 #' @examples
 #' \dontrun{
 #' library(DynareR)
-#' # include_IRF(model="BKK",IRF="E_H2",path=".")
-#'}# The above code fetches the IRF graph from "BKK/BKK/graphs/BKK_IRF_E_H2.pdf"
+#'
+#' demo(bkk)
+#'
+#' include_IRF(model="bkk",IRF="E_H2")
+#'
+#' # The above code fetches the IRF graph from "bkk/bkk/graphs/bkk_IRF_E_H2.pdf"
+#'
+#' # Alternatively, the `path` argument can be used as follows
+#'
+#' include_IRF(path="bkk/bkk/graphs/bkk_IRF_E_H2.pdf")
+#'}
 #' @references Bob Rudis (2015).Running Go language chunks in R Markdown (Rmd) files. Available at:  https://gist.github.com/hrbrmstr/9accf90e63d852337cb7
 #'
 #' Yihui Xie (2019). knitr: A General-Purpose Package for Dynamic Report Generation in R. R package version 1.24.
@@ -22,15 +31,15 @@
 #'
 #' Yihui Xie (2014) knitr: A Comprehensive Tool for Reproducible Research in R. In Victoria Stodden, Friedrich Leisch and Roger D. Peng, editors, Implementing Reproducible Computational Research. Chapman and Hall/CRC. ISBN 978-1466561595
 #'
-#' @seealso  write_mod write_dynare run_model run_dynare
+#' @family important functions
 #' @keywords documentation
 #' @export
-include_IRF <- function(model="",IRF="",path=".") {
-    IRFPath=paste0(path,"/",model,"/",model,"/","graphs/",model,"_IRF_",IRF,".pdf")
-    # if(!exists(IRFPath)) IRFPath=paste0(path,"/",model,"/",model,"/","graphs/",model,"_IRF_",IRF,".eps")
-    if(!exists(IRFPath)) IRFPath=paste0(path,"/",model,"/",model,"/",model,"/","graphs/",model,"_IRF_",IRF,".pdf")
-    # if(!exists(IRFPath)) IRFPath=paste0(path,"/",model,"/",model,"/",model,"/","graphs/",model,"_IRF_",IRF,".eps")
-    IRFPath=gsub("^\\./","",IRFPath)
-    knitr::include_graphics(IRFPath)
+include_IRF <- function(path=".",model="",IRF="") {
+
+  if(path!=".") IRFPath=path
+
+  if(path=="." && model!="" && IRF!="") IRFPath=paste0(model,"/",model,"/","graphs/",model,"_IRF_",IRF,".pdf")
+
+  include_graphics(IRFPath)
 }
 
